AddChainResponse

Struct AddChainResponse 

pub struct AddChainResponse {
    pub sct_version: u8,
    pub id: String,
    pub timestamp: u64,
    pub extensions: String,
    pub signature: String,
}

Fields

sct_version: u8

The version of the SignedCertificateTimestamp structure, in decimal. A compliant v1 implementation MUST NOT expect this to be 0 (i.e., v1).

id: String

The log ID, base64 encoded. Since log clients who request an SCT for inclusion in TLS handshakes are not required to verify it, we do not assume they know the ID of the log.

timestamp: u64

The SCT timestamp, in decimal.

extensions: String

An opaque type for future expansion. It is likely that not all participants will need to understand data in this field. Logs should set this to the empty string. Clients should decode the base64-encoded data and include it in the SCT.

signature: String

The SCT signature, base64 encoded.